import csv


def csv_to_dict(primary_key, input_file_path):
    """Description:
        Reads CSV file and turns it into a dictionary

    Args:
        primary_key (str): Becomes the `key` of each dictionary entry
        input_file_path (str): Input file path

    Example:
        Example CSV file:

            Id,Email
            1,john@example.com
            2,jane@example.com

        Example usage:

            from pprint import pprint

            output = csv_to_dict('accounts.csv')
            print(output)
            {'1': {'Email': 'john@example.com'}, '2': {'Email': 'jane@example.com'}}

    Returns:
        list
    """
    output = {}

    dict_reader = csv.DictReader(open(input_file_path))
    for row in dict_reader:
        primary_value = row.pop(primary_key)

        output[primary_value] = {}

        for row_key, row_value in row.items():
            output[primary_value][row_key] = row_value

    return output


def csv_to_list(input_file_path):
    """Description:
        Reads CSV file and turns it into a list

    Args:
        input_file_path (str): Input file path

    Example:
        Example CSV file:

            Id,Email
            1,john@example.com
            2,jane@example.com

        Example usage:

            from pprint import pprint

            output = csv_to_list('accounts.csv')
            pprint(output)
            [{'Email': 'john@example.com', 'Id': '1'},
            {'Email': 'jane@example.com', 'Id': '2'}]

    Returns:
        list
    """
    output = []
    dict_reader = csv.DictReader(open(input_file_path))

    for row in dict_reader:
        csv_dict = {}

        for key, value in row.items():
            csv_dict[key] = value

        output.append(csv_dict)

    return output



"""Miscellaneous functions used to fulfill common requirements


## Example

Example CSV file, `accounts.csv`:

    Id,Email
    1,john@example.com
    2,jane@example.com

Example usage:

    from pprint import pprint

    list_output = csv_to_list('accounts.csv')
    pprint(list_output)
    [{'Email': 'john@example.com', 'Id': '1'},
    {'Email': 'jane@example.com', 'Id': '2'}]

    dict_ouput = csv_to_dict('Id', 'accounts.csv')
    pprint(dict_ouput)
    {'1': {'Email': 'john@example.com'}, '2': {'Email': 'jane@example.com'}}

## Installation

    pip3 install onnmisc

## Contact

* Code: [onnmisc](https://github.com/OzNetNerd/onnmisc)
* Blog: [oznetnerd.com](https://oznetnerd.com)
* Email: [will@oznetnerd.com](mailto:will@oznetnerd.com)

"""

from .csv_funcs import *



from setuptools import setup, find_packages

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='onnmisc',
    version='0.0.1',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    url='https://onnmisc.oznetnerd.com',
    install_requires=[],
    license='',
    author='Will Robinson',
    author_email='will@oznetnerd.com',
    description='Miscellaneous functions used to fulfill common requirements'
)
